@@ -39,6 +39,7 @@ class Status:
                         "user": self.father.framework.machine.user,
                         "workspace": self.father.framework.machine.workspace,
                         "machine_path": self.father.framework.machine.machine_path,
+                        "control": int(self.father.framework.machine.get_user_config_value("BASE", "CONTROL") or 0),
                         "increments": [value.replace("mm", "") for value in inifile.find("DISPLAY", "INCREMENTS").split(",")],
                         "coordinates": list(inifile.find("TRAJ", "COORDINATES")) or [],
                         "linear_units": inifile.find("TRAJ", "LINEAR_UNITS") or "mm",
@@ -63,15 +64,16 @@ class Status:
                         },
                         "feed": {
                             "max_override": float(inifile.find("DISPLAY", "MAX_FEED_OVERRIDE")),
+                            "rate": float(self.father.framework.machine.info["feedrate"])
                         },
-                        "ext_info": self.father.framework.machine.get_user_config_items("EXTINFO")
+                        "ext_info": self.father.framework.machine.get_user_config_items("EXTINFO"),
+                        "max_linear_velocity": float(inifile.find("DISPLAY", "MAX_LINEAR_VELOCITY")),
+                        "max_velocity": float(self.father.framework.machine.info["max_velocity"]),
+                        "default_linear_velocity": float(inifile.find("DISPLAY", "DEFAULT_LINEAR_VELOCITY")),
+                        "max_angular_velocity": float(inifile.find("DISPLAY", "MAX_ANGULAR_VELOCITY")),
+                        "default_angular_velocity": float(inifile.find("DISPLAY", "DEFAULT_ANGULAR_VELOCITY"))
                     }
 
-                    user_data["ext_info"]["max_linear_velocity"] = float(inifile.find("DISPLAY", "MAX_LINEAR_VELOCITY"))
-                    user_data["ext_info"]["default_linear_velocity"] = float(inifile.find("DISPLAY", "DEFAULT_LINEAR_VELOCITY"))
-                    user_data["ext_info"]["max_angular_velocity"] = float(inifile.find("DISPLAY", "MAX_ANGULAR_VELOCITY"))
-                    user_data["ext_info"]["default_angular_velocity"] = float(inifile.find("DISPLAY", "DEFAULT_ANGULAR_VELOCITY"))
-
                     self.father.framework.machine.info["user_data"] = user_data
 
                     self.father.framework.machine.axis = user_data["coordinates"]
