@@ -8,7 +8,6 @@ import os
 import serial
 import binascii
 import threading
-import configparser
 
 class HandWheel:
 
@@ -58,7 +57,7 @@ class HandWheel:
             if self.status:
                 if len(self.joy_speed) == 0:
                     if len(self.package.framework.machine.axis) > 0:
-                        self.joy_speed = self.package.framework.machine.get_user_configs("EXTINFO")
+                        self.joy_speed = self.package.framework.machine.get_user_config_items("EXTINFO")
                     continue
                 if self.joy_count_time > 1:
                     self.do_joy()
@@ -153,7 +152,7 @@ class HandWheel:
                     self.last_joy_speed = 0
                     self.last_jpy_dir = None
                     self.use_joy = False
-            self.package.framework.utils.set_sleep(0.1)
+            self.package.framework.utils.set_sleep(0.06)
 
     def do_joy(self):
         jog_length = 0
@@ -201,7 +200,7 @@ class HandWheel:
             return
         axis_tmp = axis[3]
         axis_tmp = axis_tmp.upper()
-        if self.package.framework.armcnc.command.is_all_homed() and axis_tmp != "A":
+        if self.package.framework.armcnc.command.is_homed() and axis_tmp != "A":
             self.axis_num = 4
 
     def str2hex(self, joy):
